View source: R/make_word_lists.R
| list.table.chart | R Documentation |
This method basically makes a visual plot of a list table (which you call first).
list.table.chart(
model.list,
M = 100,
linespace = 4,
ytick = NULL,
dates = NULL,
main = paste("Word Appearance for ", attr(model.list, "topic"), "\n(Method: ",
attr(model.list, "method"), ")", sep = ""),
xlab = "Model",
mar = c(3, 5, 2.5, 0.1),
xaxt = "y",
color.breaks = NULL,
color.ramp = NULL,
...
)
model.list |
Matrix (or data.frame) from the make.list.table call. |
M |
is the max number of words to show in chart |
linespace |
Where to space |
ytick |
Put y tick marks |
dates |
Dates to put on bottom |
main |
Main title |
xlab |
Label for x-axis |
mar |
Margin of plot (see par) |
xaxt |
Plot an x-axis (see par) |
color.breaks |
Cut-points (like on a histogram) defining the different color levels. |
color.ramp |
List of colors to use from lowest value (potentially negative weights) to highest. If both color.breaks and color.ramp passed, color.breaks is list one longer than color.ramp. |
... |
Extra arguments for the core image() call that plots the word weights. |
make.list.table
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.