make.path.matrix: Generate matrix describing gradient descent path of textreg.

View source: R/sequenceplotter.R

make.path.matrixR Documentation

Generate matrix describing gradient descent path of textreg.

Description

Generate a matrix of the sequence of features as they are introduced with the textreg gradient descent program along with their coefficients with each step of the descent.

Usage

make.path.matrix(res)

Arguments

res

A textreg.result object.

See Also

Other plot.path.matrix: path.matrix.chart(), plot.textreg.result()

Examples

data( testCorpora )
testI = testCorpora$testI
res = textreg( testI$corpus, testI$labelI, c("frog","goat","bat"), C=2, verbosity=0 )	
make.path.matrix( res )

textreg documentation built on Sept. 17, 2026, 1:07 a.m.