View source: R/vizualize_phrases.R
| make.phrase.correlation.chart | R Documentation |
Make simple chart showing which phrases have substantial overlap with other phrases.
make.phrase.correlation.chart(
result,
count = FALSE,
num.groups = 5,
use.corrplot = FALSE,
...
)
result |
textreg.result object or a similarity matrix from a make.similarity.matrix call. |
count |
Display counts rather than similarity scores. |
num.groups |
Number of groups to box. |
use.corrplot |
Use the corrplot package of Taiyun Wei (will need to install it). |
... |
Extra arguments to pass to the image() plotting command. See par. |
Other Phrase Vizualization:
cluster.phrases(),
make.appearance.matrix(),
make.similarity.matrix()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.