make.phrase.matrix: Make a table of where phrases appear in a corpus

View source: R/text_searching.R

make.phrase.matrixR Documentation

Make a table of where phrases appear in a corpus

Description

Generate a n by p phrase count matrix, with n being number of documents and p being number of phrases:

0 0 0 0 0
1 6 2 0 0
8 0 0 0 0

This is the phrase equivilent of a document-term matrix.

Usage

make.phrase.matrix(phrase_list, corpus)

Arguments

phrase_list

List of strings

corpus

A corpus object from tm package

Value

a n X p matrix, n being number of documents, p being number of phrases.

See Also

Other textregCounting: make.count.table(), phrase.count()

Examples

library( tm )
data( bathtub )
lbl = meta( bathtub )$meth.chl
head( make.phrase.matrix( c("bathtub","strip+", "vapor *"), bathtub ) )

textreg documentation built on Sept. 17, 2026, 1:07 a.m.