View source: R/vizualize_phrases.R
| make.similarity.matrix | R Documentation |
First get phrase appearance pattern on positive labeling (if not directly passed) and then calculate similarity matrix of how they are similar to each other.
make.similarity.matrix(result)
result |
An textreg.result object or a matrix from make.appearance.matrix |
Warning: for 'negative weight' phrases this method does not do well since it ignores negative documents.
Other Phrase Vizualization:
cluster.phrases(),
make.appearance.matrix(),
make.phrase.correlation.chart()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.