make_search_phrases: Convert phrases to appropriate search string.

View source: R/text_searching.R

make_search_phrasesR Documentation

Convert phrases to appropriate search string.

Description

Will change, e.g., "test * pig+" to appropriate regular expression to find in the text.

Usage

make_search_phrases(phrases)

Arguments

phrases

List of strings denoting the phrases to be searched for.


textreg documentation built on Sept. 17, 2026, 1:07 a.m.