phrase.matrix: Make matrix of where phrases appear in corpus.

View source: R/prediction_code.R

phrase.matrixR Documentation

Make matrix of where phrases appear in corpus.

Description

Construct a $n X p$ matrix of appearances for selected phrases out of textreg object. $n$ is the number of documents, $p$ is the number of phrases selected in the result object ‘rules.’

Usage

phrase.matrix(rules, n)

Arguments

rules

Either a textreg.result object or the rules list from such an object.

n

(Optional) If giving a rules list, the number of documents in corpus.


textreg documentation built on Sept. 17, 2026, 1:07 a.m.