plot.textreg.result: Plot the sequence of features as they are introduced with the...

View source: R/sequenceplotter.R

plot.textreg.resultR Documentation

Plot the sequence of features as they are introduced with the textreg gradient descent program.

Description

Simply calls path.matrix.chart.

Usage

## S3 method for class 'textreg.result'
plot(x, ...)

Arguments

x

A textreg.result object.

...

Parameters to be passed to path.matrix.chart.

See Also

path.matrix.chart

Other plot.path.matrix: make.path.matrix(), path.matrix.chart()


textreg documentation built on Sept. 17, 2026, 1:07 a.m.