refit.model: Refit the labels to the selected phrases to get non-shrunk...

View source: R/prediction_code.R

refit.modelR Documentation

Refit the labels to the selected phrases to get non-shrunk predictions. (Uses logistic fit rather than linear, as well.)

Description

Refit the labels to the selected phrases to get non-shrunk predictions. (Uses logistic fit rather than linear, as well.)

Usage

refit.model(model, method = c("glm", "ols"))

Arguments

model

The textreg.result object from a text regression

method

Either "glm" or "ols". Type of model to fit.

Value

A fitted regression model


textreg documentation built on Sept. 17, 2026, 1:07 a.m.