View source: R/prediction_code.R
| reformat.textreg.model | R Documentation |
Calculate some useful statistics (percents, etc) and return as dataframe.
reformat.textreg.model(model, short = TRUE)
model |
The model returned from |
short |
True if the output should be abbrviated for easy consumption. |
Dataframe with statistics on the terms in the model
Other textreg.result:
is.textreg.result(),
phrases(),
print.textreg.result()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.