It is possibly recommended to pass a filename to the C++ function textreg
rather than the entire corpus for
large text since I believe it will otherwise copy over everything due to the coder's (my) poor
understanding of how RCpp converts objects.
save.corpus.to.files(bigcorp, filename = "corpus")