View source: R/sequenceplotter.R
| make.path.matrix | R Documentation |
Generate a matrix of the sequence of features as they are introduced with the textreg gradient descent program along with their coefficients with each step of the descent.
make.path.matrix(res)
res |
A textreg.result object. |
Other plot.path.matrix:
path.matrix.chart(),
plot.textreg.result()
data( testCorpora )
testI = testCorpora$testI
res = textreg( testI$corpus, testI$labelI, c("frog","goat","bat"), C=2, verbosity=0 )
make.path.matrix( res )
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.