View source: R/text_searching.R
| make_search_phrases | R Documentation |
Will change, e.g., "test * pig+" to appropriate regular expression to find in the text.
make_search_phrases(phrases)
phrases |
List of strings denoting the phrases to be searched for. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.