View source: R/text_searching.R
| tm_gregexpr | R Documentation |
Pull out content of a tm corpus and call gregexpr on that content represented as a list of character strings.
tm_gregexpr(
pattern,
corpus,
ignore.case = FALSE,
perl = FALSE,
fixed = FALSE,
useBytes = FALSE
)
pattern |
See gregexpr |
corpus |
Either a character vector or tm Corpus object. |
ignore.case |
See gregexpr |
perl |
See gregexpr |
fixed |
See gregexpr |
useBytes |
See gregexpr |
If 'corpus' is already a character vector, it just calls gregexpr with no fuss (or warning).
This method gives results exactly as if gregexpr were called on the Corpus
represented as a list of strings.
See gregexpr.
gregexpr
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.